==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/PlaneCircleExclamation.md <==
# PlaneCircleExclamation


```text
fontawesome-6/Solid/PlaneCircleExclamation
```

```text
include('fontawesome-6/Solid/PlaneCircleExclamation')
```



| Illustration | PlaneCircleExclamation |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/PlaneCircleExclamation.png) | ![illustration for PlaneCircleExclamation](../../fontawesome-6/Solid/PlaneCircleExclamation.Local.png) |




## PlaneCircleExclamation

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PlaneCircleExclamation
include('fontawesome-6/Solid/PlaneCircleExclamation')

' renders the element
PlaneCircleExclamation('PlaneCircleExclamation', 'Plane Circle Exclamation', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PlaneCircleExclamation
include('fontawesome-6/Solid/PlaneCircleExclamation')

' renders the element
PlaneCircleExclamation('PlaneCircleExclamation', 'Plane Circle Exclamation', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/PlaneCircleExclamation.md <==
# PlaneCircleExclamation


```text
fontawesome-6/Solid/PlaneCircleExclamation
```

```text
include('fontawesome-6/Solid/PlaneCircleExclamation')
```



| Illustration | PlaneCircleExclamation |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/PlaneCircleExclamation.png) | ![illustration for PlaneCircleExclamation](../../fontawesome-6/Solid/PlaneCircleExclamation.Local.png) |




## PlaneCircleExclamation

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PlaneCircleExclamation
include('fontawesome-6/Solid/PlaneCircleExclamation')

' renders the element
PlaneCircleExclamation('PlaneCircleExclamation', 'Plane Circle Exclamation', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element PlaneCircleExclamation
include('fontawesome-6/Solid/PlaneCircleExclamation')

' renders the element
PlaneCircleExclamation('PlaneCircleExclamation', 'Plane Circle Exclamation', 'an optional tech label', 'an optional description')
@enduml
```
